@@ -29,6 +29,7 @@
 
 #include "aneditor.h"
 
+#include <libanjuta/anjuta-plugin.h>
 #include <libanjuta/anjuta-status.h>
 #include <libanjuta/anjuta-encodings.h>
 
@@ -85,6 +86,7 @@ struct _TextEditor
 	/* Settings */
 	GSettings *settings;
 	GSettings *docman_settings;
+	GSettings *msgman_settings;
 
 	/* Editor ID and widget for AnEditor */
 	AnEditorID editor_id;
@@ -143,7 +145,7 @@ struct _TextEditorClass
 GType text_editor_get_type (void);
 
 /* New instance of TextEditor */
-GtkWidget* text_editor_new (AnjutaStatus *status, AnjutaShell* shell, const gchar *uri,
+GtkWidget* text_editor_new (AnjutaPlugin *plugin, const gchar *uri,
 							const gchar *tab_name);
 
 /* Freeze and thaw editor */
@@ -287,6 +289,10 @@ void text_editor_scintilla_command (TextEditor *te, gint command,
 #define DOCMAN_PREF_SCHEMA  "org.gnome.anjuta.document-manager"
 #define TEXT_ZOOM_FACTOR           "text-zoom-factor"
 
+#define MSGMAN_PREF_SCHEMA "org.gnome.anjuta.message-manager"
+#define MSGMAN_COLOR_ERROR                "msgman-color-error"
+#define MSGMAN_COLOR_WARNING              "msgman-color-warning"
+
 #define PREF_SCHEMA		"org.gnome.anjuta.scintilla"
 /* Editor preferences */
 #define DISABLE_SYNTAX_HILIGHTING  "disable-syntax-hilighting"
